
# Created by Amin Rahmani, Ph.D., P.E. - July 15, 2018
# Copyright © 2018 Amin Rahmani. All rights reserved.

#========================================================================================
#                               ****   Notes  ****
# This code performs lateral soil-pile interaction analysis under static loadings, only. May not be adequate for axial and seismic loading conditions.
# You need to makes changes on the lines that the comment "User-Defined" appears. Please go through all the command lines before running it.
# Units are in Metric (kN, ton, sec, m). Check the units if you work with Imperial units. 
# Outputs will be saved in a folder titled "Outputs".
# Since the model uses contact3D elements which is highly nonlinear, it is recommended to use very mesh.
#========================================================================================

wipe all

set startT [clock seconds]

##### This will create an input file for GID program if you want to check the final geometry.
set meshFile [open soilmesh.flavia.msh w]
##########################################################################################
	

#######################################################################
#### Input parameters used for creating the geometry of soil-pile model 
#######################################################################

set gravX  0.0000
set gravY  0.0000
set gravZ -9.8100				   ;# gravity in direction Z. The value would be -32.2 if Imperial units are used.

set BP       0.32                         ;# User-defined --- pile width                                         
set LP       13.0                        ;# User-defined --- pile length --- ** Note: Zone meshing in vertical direction should be consistent with the pile length.
						                 ;# zo and z1 defined below should be set in a way that LP >= z0+z1
set HZ       27.0                        ;# User-defined --- Model total height

#### You can apply 3 levels of mesh sizes in the horizontal direction, zone 0, 1, 2, and 3 represent areas from farthest to nearest to pile center.
set xSize0   2.0                           ;# User-Defined --- x direction element size - zone 0 
set ySize0   2.0                           ;# User-Defined --- y direction element size - zone 0
set xSize1   [expr $BP*2.0]                ;# x direction element size - zone 1
set ySize1   [expr $BP*2.0]                ;# y direction element size - zone 1
set xSize2   [expr $BP*1.0]                ;# x direction element size - zone 2
set ySize2   [expr $BP*1.0]                ;# y direction element size - zone 2
set xSize3   [expr $BP/2.0]                ;# x direction element size - zone 3 (within pile physical volume)
set ySize3   [expr $BP/2.0]                ;# y direction element size - zone 3 (within pile physical volume)

set WInf     [expr $BP/2.0]			 ;#  Thickness of a layer of soil ringing the pile representing interface element - NOT APllicable for this analysis

# Total length and width of the model
set LX       [expr 2*($WInf+0.5*$BP+8*$BP+10.0)]                  ;# User defined --- Model lenght in direction X. Modify the number "0.0" in a way that LX match the length of your model.       
set BY       [expr 2*($WInf+0.5*$BP+8*$BP+10.0)]                  ;# User defined --- Model width in direction Y. Modify the number "0.0" in a way that BY match the width of your model.  

#### You can apply 3 levels of mesh sizes in the vertical direction, z0, z1, and z2 represent layer thichness at the top, middle, and bottom layers.
set z0 4.0   					;# User-Defined - total thickness of zone z0
set z1 9.0 					;# User-Defined - total thickness of zone z1
								; # zo and z1 should be set in a way that LP >= z0+z1
set z2 14.0 						;# User-Defined - total thickness of zone z2
 
set zSize0    0.5               ;# User-Defined - element thickness in zone z0
set zSize1    1.0               ;# User-Defined - element thickness in zone z1
set zSize2    2.0               ;# User-Defined - element thickness in zone z2

set numXele  [expr int(($LX-16*$BP-$BP-2*$WInf)/$xSize0 + 8*$BP/$xSize1 + 8*$BP/$xSize2 + $BP/$xSize3+2) ]        ;# number of elements in x  direction 
set numYele  [expr int(($BY-16*$BP-$BP-2*$WInf)/$ySize0 + 8*$BP/$ySize1 + 8*$BP/$ySize2 + $BP/$ySize3+2)/2.0 ]    ;# number of elements in y  direction --- *** Note *** half mesh
set numZele  [expr int($z0/$zSize0+$z1/$zSize1+$z2/$zSize2)]                                                      ;# number of elements in z  direction    direction

###########################################################
#### Creating Nodes for 3-dimensional Geometry of the soil domain
###########################################################

model basic -ndm 3 -ndf 3

#### For GID Program Use
puts $meshFile "MESH stdBrick dimension 3 ElemType Hexahedra Nnode 8"
puts $meshFile "Coordinates"
######################################################################

set numXnode  [expr $numXele+1]
set numYnode  [expr int($numYele*2.0+1)]
set numZnode  [expr $numZele+1]

#set eleNum_0 [expr int($l_extra/$ySize0)]
set eleNum_1 [expr int(4.0*$BP/$ySize1)]
set eleNum_2 [expr int(4.0*$BP/$ySize2)]
set m 0
for {set i 1} {$i <= $numXnode} {incr i 1} {
  for {set j 1} {$j <= $numYnode} {incr j 1} {
    for {set k 1} {$k <= $numZnode} {incr k 1} {

      if { $i == [expr int($numXele/2.0)] && $j == $numYele} {
           set xdim [expr $LX/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
      } else {
        if { $i == [expr int($numXele/2.0+2)] && $j == $numYele} {
           set xdim [expr $LX/2 + $BP*(0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
      } else {
        if { $i == [expr int($numXele/2.0)] && $j == [expr int($numYele+2)]} {
           set xdim [expr $LX/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 + $BP*(0.5*pow(2,0.5))/2]
      } else {
        if { $i == [expr int($numXele/2.0+2)] && $j == [expr int($numYele+2)]} {
           set xdim [expr $LX/2 + $BP*(0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 + $BP*(0.5*pow(2,0.5))/2]
      } else {

      ### nodes xdim in zone 0
      if { $i <= [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf )/$xSize0+1)] } {                                               
         set xdim [expr ($i-1)*$xSize0] 
      } else {
        if { $i > [expr $numXnode - ($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0 ] } {
           set xdim [expr $LX-($numXnode-$i)*$xSize0]
      ### nodes xdim in zone 1
      } else {
        if { $i > [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+1)] && $i <= [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0 + (8*$BP)/(2*$xSize1) +1) ] } {
             set xdim [expr ($xSize1*($i-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0 + 1)) + $xSize0*($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0 ) ]             
      } else { 
        if { $i > [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+(8*$BP)/(2*$xSize1) + (8*$BP)/($xSize2)+ $BP/$xSize3 +2+ 1)] && $i <= [expr $numXnode-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0) ] } { 
             set xdim [expr $LX/2.0 + $BP/2.0 + $WInf + 4*$BP + ($i-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+ 8*$BP/(2*$xSize1)+(8*$BP)/$xSize2 + $BP/$xSize3+ 2 +1))*$xSize1]
      ### nodes xdim in zone 2 
      } else {
        if { $i > [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+(8*$BP)/(2*$xSize1) + 1)] && $i <= [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+(8*$BP)/(2*$xSize1) + (8*$BP)/(2*$xSize2) +1)] } {
             set xdim [expr ($LX/2.0- $BP/2.0-4*$BP-$WInf + ($i-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+(8*$BP)/(2*$xSize1) +1))*$xSize2)]
      } else { 
        if { $i > [expr (($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0)+(8*$BP)/(2*$xSize1)+(8*$BP)/(2*$xSize2)+$BP/$xSize3+ 2 + 1] && $i <= [expr $numXnode-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0-4*$BP/$xSize1) ] } { 
             set xdim [expr ($LX/2.0+ $BP/2.0 +$WInf+ ( $i-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+(8*$BP)/(2*$xSize1)+(8*$BP)/(2*$xSize2)+$BP/$xSize3+2 +1))*$xSize2)]
      ### nodes xdim in zone 3
      } else {
        if { $i == $numXele/2 } {
             set xdim [ expr $LX/2- $BP/2]
      } else {
        if  { $i == $numXele/2 +3 } {
             set xdim [ expr $LX/2+ $BP/2+$WInf]
      } else {

             set xdim   [expr ($LX/2.0-$BP/2.0+($i-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+ 8*$BP/(2*$xSize1)+8*$BP/(2*$xSize2)+1+1))*$xSize3) ]   
             }        
      }
      }
      }
      }
      }
      }
      }

      ### nodes ydim in zone 0
      if { $j <= [expr (($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0+1)] } {                                               
         set ydim [expr ($j-1)*$ySize0] 
        
      ### nodes ydim in zone 1
      } else {
        if { $j > [expr (($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0+1)] && $j <= [expr (($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0 + (8*$BP)/(2*$ySize1) + 1) ] } {
             set ydim [expr ($ySize1*($j-(($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0 + 1)) + $ySize0*($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0 ) ]             

      ### nodes ydim in zone 2 
      } else {
        if { $j > [expr (($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0+(8*$BP)/(2*$ySize1) + 1)] && $j <= [expr (($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0+(8*$BP)/(2*$ySize1) + (8*$BP)/(2*$ySize2) +1)] } {
             set ydim [expr ($BY/2.0- $BP/2.0-$WInf-4*$BP + ($j-(($BY/2.0-8*$BP-$BP/2.0-$WInf)/$ySize0+(8*$BP)/(2*$ySize1) +1))*$ySize2)]
      ### nodes ydim in zone 3
      } else {
         if { $j == $numYele} {
            set ydim [ expr $BY/2- $BP/2]
      } else {
         if { $j == [expr $numYele+1] || $j == [expr $numYele+2] } {
             set ydim   [expr ($BY/2.0-$BP/2.0 + ($j-$numYele)*$ySize3) ]    
      } else {
         if { $j == [expr $numYele+3] } {
             set ydim [expr $BY/2.0+$BP/2.0+$WInf ]
      } else {
         if { $j > [expr $numYele+3] && $j <= [expr $numYele+1+1+$eleNum_2+1] } {
             set ydim [expr $BY/2.0+$BP/2.0+$WInf+($j-($numYele+3))*$ySize2 ]
      } else {
         if { $j > [expr $numYele+1+1+$eleNum_2+1] && $j <= [expr $numYele+1+1+$eleNum_2+$eleNum_1+1] } {
             set ydim [expr $BY/2.0+$BP/2.0+$WInf+4.0*$BP+($j-($numYele+1+1+$eleNum_2+1))*$ySize1 ]
      } else {
         if { $j > [expr $numYele+1+1+$eleNum_2+$eleNum_1+1] } {
             set ydim [expr $BY/2.0+$BP/2.0+$WInf+8.0*$BP+($j-($numYele+1+1+$eleNum_2+$eleNum_1+1))*$ySize0 ]
     
      }
      }}
      }}}}}}
}
}
}
}
      if { $k <= [expr ($z2/$zSize2+1)] } {
          set   zdim [expr ($k-1)*$zSize2]
      } else {
         if { $k > [expr ($z2/$zSize2)+($z1/$zSize1)+1] } {
          set   zdim [expr $z2+$z1+($k-(($z2/$zSize2)+($z1/$zSize1)+1))*$zSize0]
      } else {
          set   zdim [expr $z2+($k-(($z2/$zSize2)+1))*$zSize1]
      }
      }
      set   nodeNum   [expr $m*$numZnode+$k] 
      node  $nodeNum  $xdim $ydim $zdim
   
	  #### For GID Program Use
      puts $meshFile "$nodeNum  $xdim $ydim $zdim"
	  #############################################
	  
###### Specifying Node numbers in center and edge of pile

if { $i == [expr $numXele/2] && $j == [ expr $numYele ] && $k == [ expr int(($HZ-$LP)/$zSize2+1) ] } {
    set p1 $nodeNum
    #puts "p1=$p1"
   } else {
   if { $i == [expr $numXele/2+1] && $j == [ expr $numYele ] && $k == [ expr int(($HZ-$LP)/$zSize2+1) ] } {
    set p2 $nodeNum
    #puts "p2=$p2"
   } else {
   if { $i == [expr $numXele/2+2] && $j == [ expr $numYele ] && $k == [ expr int(($HZ-$LP)/$zSize2+1) ] } {
    set p3 $nodeNum
    #puts "p3=$p3"
   }
   } 
   }
   }
    set m [expr ($m+1)]
  } 
}

#### For GID Program Use
puts $meshFile "end coordinates"
#################################

##########################################
#### Define Soil Materials
##########################################

# User-Defined --- define behavior of soil at different layers

##layer 1: It is recommended to force the model to ignore soil stiffness and strength in the upper 1 meter (3 feet). 
set rhof    1.0
set cohes1  5.0 ; #Neglect soil strength in the upper 1 meter (3 feet)
set Gs1     [expr 10.0*$cohes1] ; #Neglect soil stiffness in the upper 1 meter (3 feet)
set nou1    0.45
###set Es1     [expr 9.0*$Bs1*$Gs1/(3.0*$Bs1+$Gs1)]
set Bs1            [expr 2.0*$Gs1*(1+$nou1)/3.0/(1-2.0*$nou1)]
set rhos1   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 1 3 $rhos1  $Gs1 $Bs1 $cohes1 $peakShearStra ;#0.1 101.3 0.5 20

##layer 2
set cohes2  32.2
set nou2    0.45
set Gs2      [expr 100.0*$cohes2]
set Bs2       [expr 2.0*$Gs2*(1+$nou2)/3.0/(1-2.0*$nou2)]
set rhos2   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 2 3 $rhos2  $Gs2 $Bs2 $cohes2 $peakShearStra ;#0.1 101.3 0.5 20

##layer 3
set cohes3  42.3
set nou3    0.45
set Gs3      [expr 100.0*$cohes3]
set Bs3       [expr 2.0*$Gs3*(1+$nou3)/3.0/(1-2.0*$nou3)]
set rhos3   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 3 3 $rhos3  $Gs3 $Bs3 $cohes3 $peakShearStra ;#0.1 101.3 0.5 20

##layer 4
set cohes4  17.50
set nou4    0.45
set Gs4      [expr 100.0*$cohes4]
set Bs4       [expr 2.0*$Gs4*(1+$nou4)/3.0/(1-2.0*$nou4)]
set rhos4   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 4 3 $rhos4  $Gs4 $Bs4 $cohes4 $peakShearStra ;#0.1 101.3 0.5 20

##layer 5
set cohes5  30.1
set nou5    0.45
set Gs5      [expr 100.0*$cohes5]
set Bs5       [expr 2.0*$Gs5*(1+$nou5)/3.0/(1-2.0*$nou5)]
set rhos5   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 5 3 $rhos5  $Gs5 $Bs5 $cohes5 $peakShearStra ;#0.1 101.3 0.5 20

##layer 6
set cohes6  23.4
set nou6    0.45
set Gs6      [expr 100.0*$cohes6]
set Bs6       [expr 2.0*$Gs6*(1+$nou6)/3.0/(1-2.0*$nou6)]
set rhos6   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 6 3 $rhos6  $Gs6 $Bs6 $cohes6 $peakShearStra ;#0.1 101.3 0.5 20

##layer 7
set cohes7  51.8
set nou7    0.45
set Gs7      [expr 100.0*$cohes7]
set Bs7       [expr 2.0*$Gs7*(1+$nou7)/3.0/(1-2.0*$nou7)]
set rhos7   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 7 3 $rhos7  $Gs7 $Bs7 $cohes7 $peakShearStra ;#0.1 101.3 0.5 20

##layer 8
set cohes8  29.8
set nou8    0.45
set Gs8      [expr 100.0*$cohes8]
set Bs8       [expr 2.0*$Gs8*(1+$nou8)/3.0/(1-2.0*$nou8)]
set rhos8   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 8 3 $rhos8  $Gs8 $Bs8 $cohes8 $peakShearStra ;#0.1 101.3 0.5 20

##layer 9
set cohes9  32.6
set nou9    0.45
set Gs9      [expr 100.0*$cohes9]
set Bs9       [expr 2.0*$Gs9*(1+$nou9)/3.0/(1-2.0*$nou9)]
set rhos9   [expr 2.0-$rhof]
set peakShearStra 0.1

nDMaterial PressureIndependMultiYield 9 3 $rhos9  $Gs9 $Bs9 $cohes9 $peakShearStra ;#0.1 101.3 0.5 20


# create wrapper material for initial state analysis
nDMaterial InitialStateAnalysisWrapper 100 1 3
nDMaterial InitialStateAnalysisWrapper 200 2 3
nDMaterial InitialStateAnalysisWrapper 300 3 3
nDMaterial InitialStateAnalysisWrapper 400 4 3
nDMaterial InitialStateAnalysisWrapper 600 6 3
nDMaterial InitialStateAnalysisWrapper 700 7 3
nDMaterial InitialStateAnalysisWrapper 800 8 3
nDMaterial InitialStateAnalysisWrapper 900 9 3

##########################################
#### Define Soil Elements
##########################################

#### For GID Program Use
puts $meshFile "Elements"
#################################

set m 0

for {set i 1} {$i <= $numXele } {incr i 1} {
  for {set j 1} {$j <= [expr int($numYele*2.0)] } {incr j 1} {
    for {set k 1} {$k <= $numZele} {incr k 1} {
      
      set eleNum [expr $m*$numZele+$k] 
      set n1  [expr ($i-1)*($numYnode*$numZnode)+$k+($j-1)*$numZnode] 
      set n2  [expr $n1+($numYnode*$numZnode)] 
      set n3  [expr $n2+$numZnode] 
      set n4  [expr $n1+$numZnode] 
      set n5  [expr $n1+1]
      set n6  [expr $n2+1]
      set n7  [expr $n3+1]
      set n8  [expr $n4+1]
      
	# User-Defined --- Assign appropriate material tag to soil elements

      if { $k == 24 || $k == 23 } {    ;# User-Defined --- Assign appropriate material tag to soil elements                      	   
        element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 100 0.0 0.0 [expr $gravZ*$rhos1]
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 1"
      } else { 
	  if { $k == 22 || $k == 21 } {  ;# User-Defined --- Assign appropriate material tag to soil elements
        element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 200 0.0 0.0 [expr $gravZ*$rhos2]
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 2"
	  } else { 
	  if { $k == 20 || $k == 19 } {  ;# User-Defined --- Assign appropriate material tag to soil elements
	    element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 300 0.0 0.0 [expr $gravZ*$rhos3]
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 3"
	  } else { 
	  if { $k == 18 || $k ==17} {    ;# User-Defined --- Assign appropriate material tag to soil elements
	    element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 400 0.0 0.0 [expr $gravZ*$rhos4]	
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 4"   
	  } else {
	  if { $k == 16 } {              ;# User-Defined --- Assign appropriate material tag to soil elements
	    element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 600 0.0 0.0 [expr $gravZ*$rhos6]	
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 6"   
	  } else {
	  if { $k == 15 } {              ;# User-Defined --- Assign appropriate material tag to soil elements
	    element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 700 0.0 0.0 [expr $gravZ*$rhos7]	
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 7"   
	  } else {
	  if { $k == 14 || $k == 13 } {  ;# User-Defined --- Assign appropriate material tag to soil elements
	    element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 800 0.0 0.0 [expr $gravZ*$rhos8]	
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 8"   
	  } else {				   ;# User-Defined --- Assign appropriate material tag to soil elements
	    element stdBrick $eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 900 0.0 0.0 [expr $gravZ*$rhos9]
		puts $meshFile "$eleNum $n1 $n2 $n3 $n4 $n5 $n6 $n7 $n8 9"
	  }}}}}}}	   	  	   

    }
    set m [expr ($m+1)]
  }
}

##############################################
#### Prints Total Number of Nodes and Elements
##############################################
puts "Number of Nodes    =  $nodeNum"
puts "Number of Elements =  $eleNum " 

#### For GID Program Use
puts $meshFile "end elements"
#############################

##############################################
#### Boundary conditions
############################################## 

# Bottom Boundary 
fixZ  0.0  1 1 1    -tol 1e-12

# Lateral Boundaries - Tied together
for {set k 2} {$k <= $numZnode} {incr k 1} {
  for {set j 2} {$j <= $numYnode} {incr j 1} {
		equalDOF $k [expr ($numXnode-1)*($numZnode*$numYnode)+$k+(($j-2)*$numZnode)]    1 2  3    ;# right side yz boundary 
		equalDOF $k [expr ($j-1)*$numZnode+$k]     1  2  3                                        ;# left  side yz boundary                     
        
  }
  for {set i 2} {$i <=  ($numXnode)} {incr i 1} {
		equalDOF $k [expr ($i-1)*($numZnode*$numYnode)+$k]          1 2 3                ;# right side xz boundary
		equalDOF $k [expr $i*($numZnode*$numYnode)+$k-$numZnode]    1 2  3               ;# left  side xz boundary
  }
}

puts " ## Soil is built!! ## "

# turn on initial state analysis feature
InitialStateAnalysis on

##############################################
#### Elastic Geostatic Analysis
##############################################

numberer Plain
#system SparseSYM
system Mumps
test NormDispIncr 1.0e-3 100 1
algorithm KrylovNewton
constraints Penalty 1.e18 1.e18
integrator Newmark 0.5 0.25
analysis Transient 

 for {set numIncr 1} {$numIncr <= 5 } {incr numIncr 1} {
       puts "##### Elastic Geostatic Analysis step : $numIncr #####";
       analyze 1 10.0
     }

##############################################
#### Switch into Plastic State 
##############################################

# User-Defined
updateMaterialStage -material 100 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 200 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 300 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 400 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
#updateMaterialStage -material 500 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 600 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 700 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 800 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.
updateMaterialStage -material 900 -stage 1	; #User-Defined --- Must be modified per the number of material types and tags.


for {set numIncr 1} {$numIncr <= 5 } {incr numIncr 1} {
      puts "##### Plastic Geostatic Analysis step : $numIncr #####";
      analyze 1 0.01
    }

##############################################
#### Introduce Pile into the Numerical Model
##############################################

##############################################
#### Define Pile Nodes
##############################################

model basic -ndm 3 -ndf 6

#### For GID Program Use
puts $meshFile "MESH beamcolumn dimension 3 ElemType linear Nnode 2"
puts $meshFile "Coordinates"
#######################################################################

set m 0
set s 1000000
set n $p2

for {set i 2} {$i <= 2} {incr i 1} {
  for {set j 2} {$j <= 2} {incr j 1} {
    for {set k 1} {$k <= [expr int($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2+1)]} {incr k 1} {

      if { $i == 1 && $j == 1} {
           set xdim [expr $LX/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
      } else {
        if { $i == 3 && $j == 1} {
           set xdim [expr $LX/2 + $BP*(0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
      } else {
        if { $i == 1 && $j == 3} {
           set xdim [expr $LX/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 + $BP*(0.5*pow(2,0.5))/2]
      } else {
        if { $i == 3 && $j == 3} {
           set xdim [expr $LX/2 + $BP*(0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 + $BP*(0.5*pow(2,0.5))/2]
      } else {

      set xdim [expr ($i-1)*$xSize3 + $LX/2.0 - $BP/2.0]
      set ydim [expr ($j-1)*$ySize3 + $BY/2.0 - $BP/2.0]
      }
      }
	}
	}

	if { $k == 1 } {
          set   zdim [expr ($k-1)*$zSize2 + $HZ   -   $LP + 0.0]
      } else {  
      if { $k <= [expr ($LP-$z0-$z1)/$zSize2+1] } {
          set   zdim [expr ($k-1)*$zSize2 + $HZ   -   $LP + 0.1]
      } else {
        if { $k > [expr ($LP-$z0-$z1)/$zSize2+($z1/$zSize1)+1] } {
          set   zdim [expr $z2+$z1+($k-(($LP-$z0-$z1)/$zSize2+($z1/$zSize1)+1))*$zSize0 + 0.1]
      } else {
          set   zdim [expr $z2+($k-(($LP-$z0-$z1)/$zSize2+1))*$zSize1 + 0.1 ]
      }
      }}

      set nodeNum [expr int($m*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2+1)+$k+$numXnode*$numYnode*$numZnode)]
      node $nodeNum $xdim $ydim $zdim 
      
	#### For GID Program Use
      puts $meshFile "$nodeNum $xdim $ydim $zdim"
	###########################################
	  
      if { $i == 2 && $j == 2 && $k == 1 } {
         set np $nodeNum      
      }
 
       if { $i == 2 && $j == 2 && $k == 1 } {
          equalDOF  [expr $n+$k-1] $nodeNum 1 2 3 
         }  

    }     
    set m [expr ($m+1)]
    set n [expr ($n+$numZnode)]
  }
}
 

##############################################
#### Pile Nodes Boundary Conditions
##############################################

for { set i $np } { $i <= [expr int($np+($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2))]} { incr i 1 } {
   fix $i 0 1 0 1 0 1
    } 

##############################################
#### Pile Head Fixity
##############################################

#fix [expr int($np+($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2))] 0 0 0 0 0 1 ; # User Defined


##############################################
#### Define Nodes for BeamContact3D element
##############################################

model basic -ndm 3 -ndf 3

set s 1000000
set m 0
set n $p1

for {set i 1} {$i <= 3} {incr i 1} {
  if { $i == 2 } { set n $p2 }
  if { $i == 3 } { set n $p3 }
  for {set j 1} {$j <= 3} {incr j 1} {
    for {set k 2} {$k <= [expr int($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2+1)]} {incr k 1} {

      if { $i == 1 && $j == 1} {
           set xdim [expr $LX/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
      } else {
        if { $i == 3 && $j == 1} {
           set xdim [expr $LX/2 + $BP*(0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
      } else {
        if { $i == 1 && $j == 3} {
           set xdim [expr $LX/2 - $BP/2 + $BP*(1-0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 + $BP*(0.5*pow(2,0.5))/2]
      } else {
        if { $i == 3 && $j == 3} {
           set xdim [expr $LX/2 + $BP*(0.5*pow(2,0.5))/2]
           set ydim [expr $BY/2 + $BP*(0.5*pow(2,0.5))/2]
      } else {

      set xdim [expr ($i-1)*$xSize3 + $LX/2.0 - $BP/2.0]
      set ydim [expr ($j-1)*$ySize3 + $BY/2.0 - $BP/2.0]
      }
      }
	}
	}
	  
      if { $k <= [expr ($LP-$z0-$z1)/$zSize2+1] } {
          set   zdim [expr ($k-1)*$zSize2 + $HZ   -   $LP]
      } else {
        if { $k > [expr ($LP-$z0-$z1)/$zSize2+($z1/$zSize1)+1] } {
          set   zdim [expr $z2+$z1+($k-(($LP-$z0-$z1)/$zSize2+($z1/$zSize1)+1))*$zSize0]
      } else {
          set   zdim [expr $z2+($k-(($LP-$z0-$z1)/$zSize2+1))*$zSize1]
      }
      }

	if { $i == 2 && $j == 2} {
		### Lagrange multiplier nodes
		node [expr $s+1] $xdim $ydim [expr $zdim]
		node [expr $s+2] $xdim $ydim [expr $zdim]
		node [expr $s+3] $xdim $ydim [expr $zdim]
		node [expr $s+4] $xdim $ydim [expr $zdim]
		node [expr $s+5] $xdim $ydim [expr $zdim]
		node [expr $s+6] $xdim $ydim [expr $zdim]
		node [expr $s+7] $xdim $ydim [expr $zdim]
		node [expr $s+8] $xdim $ydim [expr $zdim]

		set s [expr $s+8]
	} else {
      	set nodeNum [expr int($m*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+$k+2000000)]
     		node $nodeNum $xdim $ydim $zdim 
      }

	#### For GID Program Use
      puts $meshFile "$nodeNum $xdim $ydim $zdim"
	###########################################

	 ####	 Connecting the slave nodes to the soil nodes  
       if { $i != 2 || $j != 2 } {
          equalDOF   $nodeNum [expr $n+$k-1] 1 2 3 
         } 
    }     
    set m [expr ($m+1)]
    set n [expr ($n+$numZnode)]
  }
}

########################################################
##### Remove Soil Elements Within the Pile Physical Vol.
########################################################

for { set i 0 } { $i <= 1 } { incr i 1 } {
  for { set j 0 } { $j <= 1 } { incr j 1 } {
    for { set k 1 } { $k <= [ expr ($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2) ] } { incr k 1 } {

        remove element [expr int(($numXele/2-$i)*$numYele*2.0*$numZele+($numYele-$j)*$numZele+($HZ-$LP)/$zSize2+$k)]
    }
  }
}

########################################################
##### Remove Soil Nodes Within the Pile Physical Vol.
########################################################

for { set i 1 } { $i <= [expr ($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)] } { incr i 1 } {

     remove sp   [expr int($numXele/2*$numYnode*$numZnode+$numYele*$numZnode+($HZ-$LP)/$zSize2+1+$i)] 1
     remove sp   [expr int($numXele/2*$numYnode*$numZnode+$numYele*$numZnode+($HZ-$LP)/$zSize2+1+$i)] 2
     remove sp   [expr int($numXele/2*$numYnode*$numZnode+$numYele*$numZnode+($HZ-$LP)/$zSize2+1+$i)] 3
     #remove mp   [expr int($numXele/2*$numYnode*$numZnode+$numYele*$numZnode+($HZ-$LP)/$zSize2+1+$i)]
     remove node [expr int($numXele/2*$numYnode*$numZnode+$numYele*$numZnode+($HZ-$LP)/$zSize2+1+$i)]

    }
#######################################################
#### Define Pile Cross-section - Rigid Pile
#######################################################

model basic -ndm 3 -ndf 6

### properties of piles
set D    0.32		;# User-Defined --- Pile Cross section diameter
set t    0.0127		;# User-Defined --- Pile Cross section wall thickness
set A    [expr 0.25*3.1416*pow($D,2)-0.25*3.1416*pow($D-2.0*$t,2)] 	;# User-Defined
set E     200117492.8	;# User-Defined --- Pile material elastic modulus
set G    [expr $E/2.0/(1+0.20)]
set Iz   [expr 0.25*3.1416*pow($D/2.0,4)-0.25*3.1416*pow($D/2.0-$t,4)]		;# User-Defined 
set Iy   [expr 0.25*3.1416*pow($D/2.0,4)-0.25*3.1416*pow($D/2.0-$t,4)]		;# User-Defined 
set J    [expr $Iz+$Iy]

#uniaxialMaterial Elastic 7000 $E ;# User-Defined
section Elastic 30000 $E $A $Iz $Iy $G $J
#section Fiber 30000 { 
  #patch quad  7000 10  10  [expr -$D/2.0] [expr -$D/2.0] [expr -$D/2.0] [expr $D/2.0] [expr $D/2.0] [expr $D/2.0] [expr $D/2.0] [expr -$D/2.0]
  #patch circ  7000 10 10 0.0 0.0 [expr $D/2.0-$t] [expr $D/2.0] 0.0 360.0 ;# User-Defined
  #}

#### For GID Program Use
puts $meshFile "end coordinates"
puts $meshFile "Elements"
#########################

#######################################################
#### Define Pile Elements
#######################################################

geomTransf Linear 101 1 0 0
geomTransf Linear 102 1 0 0

set ne1 $np
set numIntgrPts 5

for { set k 1 } { $k <= [ expr $z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2] } { incr k 1 } {

  element dispBeamColumn [expr $eleNum+$k] $ne1 [expr $ne1+1]   $numIntgrPts 30000  101   
  puts $meshFile "[expr $eleNum+$k] $ne1 [expr $ne1+1] 10"
  set ne1 [expr $ne1+1]

    }

#######################################################
#### Define Contact elements to Connect Pile Nodes to Surrounding Soil Nodes
#######################################################

set gTol 1.0e-10
set fTol 1.0e-10
set ne2 $np
set m 3000000
set n 0.0
set s 1000000

# User-Defined --- Contact material properties
##### Note: reduction factor of 0.55 for clays and 0.67 for sands is recommended. Parameter mu = tan (0.67*Phi)

### Interface Layer 1 (No Strength)
set mu1 0.01  		 ;# User-Defined
set G1  [expr $Gs1] ;# User-Defined
set Su1 [expr $cohes1] ;# User-Defined
nDMaterial ContactMaterial3D 12  $mu1 $G1 $Su1 0.0  

### Interface Layer 2
set mu2 0.01   ;# User-Defined
set G2  [expr 0.55*$Gs2] ;# User-Defined
set Su2 [expr 0.55*$cohes2] ;# User-Defined
nDMaterial ContactMaterial3D 22  $mu2 $G2 $Su2 0.0 

### Interface Layer 3
set mu3 0.01   ;# User-Defined
set G3  [expr 0.55*$Gs3] ;# User-Defined
set Su3 [expr 0.55*$cohes3];# User-Defined
nDMaterial ContactMaterial3D 32  $mu3 $G3 $Su3 0.0 

### Interface Layer 4
set mu4 0.01   ;# User-Defined
set G4  [expr 0.55*$Gs4];# User-Defined 
set Su4 [expr 0.55*$cohes4];# User-Defined
nDMaterial ContactMaterial3D 42  $mu4 $G4 $Su4 0.0 

### Interface Layer 6
set mu6 0.01  ;# User-Defined
set G6  [expr 0.55*$Gs6] ;# User-Defined
set Su6 [expr 0.55*$cohes6];# User-Defined
nDMaterial ContactMaterial3D 62  $mu6 $G6 $Su6 0.0 

### Interface Layer 7
set mu7 0.01  ;# User-Defined
set G7  [expr 0.55*$Gs7] ;# User-Defined
set Su7 [expr 0.55*$cohes7];# User-Defined
nDMaterial ContactMaterial3D 72  $mu7 $G7 $Su7 0.0

### Interface Layer 8
set mu8 0.01  ;# User-Defined
set G8  [expr 0.55*$Gs8] ;# User-Defined
set Su8 [expr 0.55*$cohes8];# User-Defined
nDMaterial ContactMaterial3D 82  $mu8 $G8 $Su8 0.0

### Interface Layer 9
set mu9 0.01 ;# User-Defined
set G9  [expr 0.55*$Gs9] ;# User-Defined
set Su9 [expr 0.55*$cohes9] ;# User-Defined
nDMaterial ContactMaterial3D 92  $mu9 $G9 $Su9 0.0


for { set i 2 } { $i <= [ expr int($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2+1) ] } { incr i 1 } {

	# User-Defined
      if { $i == 24 || $i == 23} {  ;# User-Defined - Assign appropraite material tag to the contact elements                       	   
		set matTag 12
      } else { 
	  if { $i == 22 || $i == 21 } {  ;# User-Defined - Assign appropraite material tag to the contact elements 
		set matTag 22
	  } else { 
	  if { $i == 20 || $i == 19 } { ;# User-Defined - Assign appropraite material tag to the contact elements 
		set matTag 32
	  } else { 
	  if { $i == 18 || $i == 17 } { ;# User-Defined - Assign appropraite material tag to the contact elements 
		set matTag 42 
	  } else {
	  if { $i == 16 } { ;# User-Defined - Assign appropraite material tag to the contact elements 
		set matTag 62  
	  } else {
	  if { $i == 15 } { ;# User-Defined - Assign appropraite material tag to the contact elements 
		set matTag 72
	  } else {
	  if { $i == 14 || $i == 13 } { ;# User-Defined - Assign appropraite material tag to the contact elements 
		set matTag 82
	  } else {
		set matTag 92
	  }}}}}}}	

    element BeamContact3D [expr $m+1] $ne2 [expr $ne2+1] [expr int(0.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+1)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+2] $ne2 [expr $ne2+1] [expr int(1.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+2)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+3] $ne2 [expr $ne2+1] [expr int(2.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+3)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+4] $ne2 [expr $ne2+1] [expr int(3.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+4)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+5] $ne2 [expr $ne2+1] [expr int(5.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+5)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+6] $ne2 [expr $ne2+1] [expr int(6.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+6)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+7] $ne2 [expr $ne2+1] [expr int(7.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+7)] [expr $BP/2.] 102 $matTag $gTol $fTol
    element BeamContact3D [expr $m+8] $ne2 [expr $ne2+1] [expr int(8.0*($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)+2000000+$i)] [expr int($s+8)] [expr $BP/2.] 102 $matTag $gTol $fTol

    set ne2 [expr $ne2+1]
    set m   [expr $m+8]
    set s   [expr $s+8]
    }        
     
#### For GID Program Use 	 
puts $meshFile "end elements"
close $meshFile
##############################


# set contact elements to be frictionless for gravity analysis
set m 3000000
setParameter -value 0 -eleRange [expr $m+1] [ expr int(($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)*8.0+$m) ] friction

###############################################
##### Final Geostatic Analysis
###############################################

test NormDispIncr 1.0e-2 100 1
constraints Penalty 1.e18 1.e18

for {set numIncr 1} {$numIncr <= 5 } {incr numIncr 1} {
      puts "##### Equilibrium Analysis step : $numIncr #####";
      analyze 1 0.01
    }

# designate end of initial state analysis (zeros displacements, keeps state variables)
InitialStateAnalysis off

# set contact elements to be frictionless for gravity analysis
set m 3000000
setParameter -value 1 -eleRange [expr $m+1] [ expr int(($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2)*8.0+$m) ] friction

##############################################
#### Update Stiffness of Materials 
##############################################	
#updateMaterials -material 100 shearModulus [expr $Gs1] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 100 bulkModulus  [expr $Bs1] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 200 shearModulus [expr $Gs2] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 200 bulkModulus  [expr $Bs2] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 300 shearModulus [expr $Gs3] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 300 bulkModulus  [expr $Bs3] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 400 shearModulus [expr $Gs4] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 400 bulkModulus  [expr $Bs4] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 600 shearModulus [expr $Gs6] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 600 bulkModulus  [expr $Bs6] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 700 shearModulus [expr $Gs7] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 700 bulkModulus  [expr $Bs7] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 800 shearModulus [expr $Gs8] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 800 bulkModulus  [expr $Bs8] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#
#updateMaterials -material 900 shearModulus [expr $Gs9] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags
#updateMaterials -material 900 bulkModulus  [expr $Bs9] ; # User-Defined --- Change Mat tag and soil parameter tag per the prescribed tags


#########################################################################
#### Record Data
#########################################################################

set dataDir Outputs
file mkdir $dataDir

## Soil Recorders
eval "recorder Node    -file $dataDir/dispsoil8BLeft.out     -time    -nodeRange [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0)*$numYnode*$numZnode+($numYele)*$numZnode+1)]                             [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0)*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]    -dof 1 2 3 disp"
eval "recorder Node    -file $dataDir/dispsoil4BLeft.out     -time    -nodeRange [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+4*$BP/$xSize1)*$numYnode*$numZnode+($numYele)*$numZnode+1)]               [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+4*$BP/$xSize1)*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]   -dof 1 2 3 disp"
eval "recorder Node    -file $dataDir/dispsoil05BLeft.out    -time    -nodeRange [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+4*$BP/$xSize1+4*$BP/$xSize2+1)*$numYnode*$numZnode+($numYele)*$numZnode+1)] [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+4*$BP/$xSize1+4*$BP/$xSize2+1)*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]   -dof 1 2 3 disp"

eval "recorder Node    -file $dataDir/dispsoil8BRight.out    -time    -nodeRange [expr int(($numXnode-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+1))*$numYnode*$numZnode+($numYele)*$numZnode+1)]                 [expr int(($numXnode-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+1))*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]    -dof 1 2 3 disp"
eval "recorder Node    -file $dataDir/dispsoil4BRight.out    -time    -nodeRange [expr int(($numXnode-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0 + 4*$BP/$xSize1 + 1))*$numYnode*$numZnode+($numYele)*$numZnode+1)]               [expr int(($numXnode-(($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0 + 4*$BP/$xSize1 + 1))*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]   -dof 1 2 3 disp"
eval "recorder Node    -file $dataDir/dispsoil05BRight.out   -time    -nodeRange [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+4*$BP/$xSize1+4*$BP/$xSize2+3)*$numYnode*$numZnode+($numYele)*$numZnode+1)] [expr int((($LX/2.0-8*$BP-$BP/2.0-$WInf)/$xSize0+4*$BP/$xSize1+4*$BP/$xSize2+3)*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]   -dof 1 2 3 disp"

eval "recorder Node    -file $dataDir/dispEdgeRight.out      -time    -nodeRange [expr int($numXele*$numYnode*$numZnode+($numYele)*$numZnode+1)] [expr int($numXele*$numYnode*$numZnode+($numYele)*$numZnode+1+$numZele)]   -dof 1 2 3 disp"

### Pile Recorders
eval "recorder Node -file $dataDir/disppile.out  -time -nodeRange $np [expr int($np+($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2))] -dof 1 2 3 4 5 6 disp"
eval "recorder Element -file $dataDir/pileforcesGlob.out  -time -eleRange  [expr $eleNum+1] [expr int($eleNum+($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2))]     globalForce"

#########################################################################
#### Apply Load on Pile Head
#########################################################################

loadConst -time 0.0
wipeAnalysis

set headload 80.9

pattern Plain 2000 "Linear" {

 	sp [expr int($np+($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2))] 1 0.06 ;# User-Defined
	#load [expr int($np+($z0/$zSize0+$z1/$zSize1+($LP-$z0-$z1)/$zSize2))] [expr $headload] 0.0 0.0 0.0 0.0 0.0 ;# User-Defined
}

#########################################################################
#### Pile Static Analysis 
#########################################################################

set NumIncr3 160 ;# User-Defined - Number of steps

integrator LoadControl [expr 1.0/$NumIncr3] 
###integrator LoadControl 1 1 1 1
#numberer RCM
numberer Plain
#constraints Transformation
constraints Penalty 1.e12 1.e12
test NormDispIncr 1.0e-2 100 1
algorithm KrylovNewton
#algorithm Newton
#system BandGeneral
#system SparseGeneral
system Mumps
#system SparseSYM
analysis Static

 for {set numIncr 1} {$numIncr <= $NumIncr3 } {incr numIncr 1} {
       puts "##### Pushover Analysis step : $numIncr #####";
       analyze 1 
     }

puts " ## Pile Load was applied !! ## "


set endT [clock seconds]
set ElapsedTime [expr $endT-$startT]
set ElapsedHours [expr int($ElapsedTime/3600.)]
set ElapsedMins [expr int($ElapsedTime/60.-$ElapsedHours*60.)]
set ElapsedSecs [expr int($ElapsedTime-$ElapsedHours*3600-$ElapsedMins*60.)]
puts "Execution time: $ElapsedHours hours and $ElapsedMins minutes and $ElapsedSecs seconds !!"

########################################
#### End of the TCL Code
########################################

wipe



